==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/CustomerManagementService/Currency.pm <==
package Microsoft::AdCenter::V6::CustomerManagementService::Currency;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AED {
    return 'AED';
}

sub ALL {
    return 'ALL';
}

sub AMD {
    return 'AMD';
}

sub ARS {
    return 'ARS';
}

sub AUD {
    return 'AUD';
}

sub AZM {
    return 'AZM';
}

sub BGL {
    return 'BGL';
}

sub BHD {
    return 'BHD';
}

sub BND {
    return 'BND';
}

sub BOB {
    return 'BOB';
}

sub BRL {
    return 'BRL';
}

sub BYB {
    return 'BYB';
}

sub BZD {
    return 'BZD';
}

sub CAD {
    return 'CAD';
}

sub CHF {
    return 'CHF';
}

sub CLP {
    return 'CLP';
}

sub CNY {
    return 'CNY';
}

sub COP {
    return 'COP';
}

sub CRC {
    return 'CRC';
}

sub CZK {
    return 'CZK';
}

sub DKK {
    return 'DKK';
}

sub DOP {
    return 'DOP';
}

sub DZD {
    return 'DZD';
}

sub EEK {
    return 'EEK';
}

sub EGP {
    return 'EGP';
}

sub EUR {
    return 'EUR';
}

sub GBP {
    return 'GBP';
}

sub GEL {
    return 'GEL';
}

sub GTQ {
    return 'GTQ';
}

sub HKD {
    return 'HKD';
}

sub HNL {
    return 'HNL';
}

sub HRK {
    return 'HRK';
}

sub HUF {
    return 'HUF';
}

sub IDR {
    return 'IDR';
}

sub ILS {
    return 'ILS';
}

sub INR {
    return 'INR';
}

sub IQD {
    return 'IQD';
}

sub IRR {
    return 'IRR';
}

sub ISK {
    return 'ISK';
}

sub JMD {
    return 'JMD';
}

sub JOD {
    return 'JOD';
}

sub JPY {
    return 'JPY';
}

sub KES {
    return 'KES';
}

sub KGS {
    return 'KGS';
}

sub KRW {
    return 'KRW';
}

sub KWD {
    return 'KWD';
}

sub KZT {
    return 'KZT';
}

sub LBP {
    return 'LBP';
}

sub LTL {
    return 'LTL';
}

sub LVL {
    return 'LVL';
}

sub LYD {
    return 'LYD';
}

sub MAD {
    return 'MAD';
}

sub MKD {
    return 'MKD';
}

sub MNT {
    return 'MNT';
}

sub MOP {
    return 'MOP';
}

sub MVR {
    return 'MVR';
}

sub MXN {
    return 'MXN';
}

sub MYR {
    return 'MYR';
}

sub NIO {
    return 'NIO';
}

sub NOK {
    return 'NOK';
}

sub NZD {
    return 'NZD';
}

sub OMR {
    return 'OMR';
}

sub PAB {
    return 'PAB';
}

sub PEN {
    return 'PEN';
}

sub PHP {
    return 'PHP';
}

sub PKR {
    return 'PKR';
}

sub PLN {
    return 'PLN';
}

sub PYG {
    return 'PYG';
}

sub QAR {
    return 'QAR';
}

sub ROL {
    return 'ROL';
}

sub RUR {
    return 'RUR';
}

sub SAR {
    return 'SAR';
}

sub SEK {
    return 'SEK';
}

sub SGD {
    return 'SGD';
}

sub SIT {
    return 'SIT';
}

sub SKK {
    return 'SKK';
}

sub SYP {
    return 'SYP';
}

sub THB {
    return 'THB';
}

sub TND {
    return 'TND';
}

sub TRL {
    return 'TRL';
}

sub TTD {
    return 'TTD';
}

sub TWD {
    return 'TWD';
}

sub UAH {
    return 'UAH';
}

sub USD {
    return 'USD';
}

sub UYU {
    return 'UYU';
}

sub UZS {
    return 'UZS';
}

sub VEB {
    return 'VEB';
}

sub VND {
    return 'VND';
}

sub YER {
    return 'YER';
}

sub YUN {
    return 'YUN';
}

sub ZAR {
    return 'ZAR';
}

sub ZWD {
    return 'ZWD';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/CustomerManagementService/Currency.pm <==
package Microsoft::AdCenter::V6::CustomerManagementService::Currency;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V6::CustomerManagementService::Currency - Represents "Currency" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AED
ALL
AMD
ARS
AUD
AZM
BGL
BHD
BND
BOB
BRL
BYB
BZD
CAD
CHF
CLP
CNY
COP
CRC
CZK
DKK
DOP
DZD
EEK
EGP
EUR
GBP
GEL
GTQ
HKD
HNL
HRK
HUF
IDR
ILS
INR
IQD
IRR
ISK
JMD
JOD
JPY
KES
KGS
KRW
KWD
KZT
LBP
LTL
LVL
LYD
MAD
MKD
MNT
MOP
MVR
MXN
MYR
NIO
NOK
NZD
OMR
PAB
PEN
PHP
PKR
PLN
PYG
QAR
ROL
RUR
SAR
SEK
SGD
SIT
SKK
SYP
THB
TND
TRL
TTD
TWD
UAH
USD
UYU
UZS
VEB
VND
YER
YUN
ZAR
ZWD

=cut

sub AED {
    return 'AED';
}

sub ALL {
    return 'ALL';
}

sub AMD {
    return 'AMD';
}

sub ARS {
    return 'ARS';
}

sub AUD {
    return 'AUD';
}

sub AZM {
    return 'AZM';
}

sub BGL {
    return 'BGL';
}

sub BHD {
    return 'BHD';
}

sub BND {
    return 'BND';
}

sub BOB {
    return 'BOB';
}

sub BRL {
    return 'BRL';
}

sub BYB {
    return 'BYB';
}

sub BZD {
    return 'BZD';
}

sub CAD {
    return 'CAD';
}

sub CHF {
    return 'CHF';
}

sub CLP {
    return 'CLP';
}

sub CNY {
    return 'CNY';
}

sub COP {
    return 'COP';
}

sub CRC {
    return 'CRC';
}

sub CZK {
    return 'CZK';
}

sub DKK {
    return 'DKK';
}

sub DOP {
    return 'DOP';
}

sub DZD {
    return 'DZD';
}

sub EEK {
    return 'EEK';
}

sub EGP {
    return 'EGP';
}

sub EUR {
    return 'EUR';
}

sub GBP {
    return 'GBP';
}

sub GEL {
    return 'GEL';
}

sub GTQ {
    return 'GTQ';
}

sub HKD {
    return 'HKD';
}

sub HNL {
    return 'HNL';
}

sub HRK {
    return 'HRK';
}

sub HUF {
    return 'HUF';
}

sub IDR {
    return 'IDR';
}

sub ILS {
    return 'ILS';
}

sub INR {
    return 'INR';
}

sub IQD {
    return 'IQD';
}

sub IRR {
    return 'IRR';
}

sub ISK {
    return 'ISK';
}

sub JMD {
    return 'JMD';
}

sub JOD {
    return 'JOD';
}

sub JPY {
    return 'JPY';
}

sub KES {
    return 'KES';
}

sub KGS {
    return 'KGS';
}

sub KRW {
    return 'KRW';
}

sub KWD {
    return 'KWD';
}

sub KZT {
    return 'KZT';
}

sub LBP {
    return 'LBP';
}

sub LTL {
    return 'LTL';
}

sub LVL {
    return 'LVL';
}

sub LYD {
    return 'LYD';
}

sub MAD {
    return 'MAD';
}

sub MKD {
    return 'MKD';
}

sub MNT {
    return 'MNT';
}

sub MOP {
    return 'MOP';
}

sub MVR {
    return 'MVR';
}

sub MXN {
    return 'MXN';
}

sub MYR {
    return 'MYR';
}

sub NIO {
    return 'NIO';
}

sub NOK {
    return 'NOK';
}

sub NZD {
    return 'NZD';
}

sub OMR {
    return 'OMR';
}

sub PAB {
    return 'PAB';
}

sub PEN {
    return 'PEN';
}

sub PHP {
    return 'PHP';
}

sub PKR {
    return 'PKR';
}

sub PLN {
    return 'PLN';
}

sub PYG {
    return 'PYG';
}

sub QAR {
    return 'QAR';
}

sub ROL {
    return 'ROL';
}

sub RUR {
    return 'RUR';
}

sub SAR {
    return 'SAR';
}

sub SEK {
    return 'SEK';
}

sub SGD {
    return 'SGD';
}

sub SIT {
    return 'SIT';
}

sub SKK {
    return 'SKK';
}

sub SYP {
    return 'SYP';
}

sub THB {
    return 'THB';
}

sub TND {
    return 'TND';
}

sub TRL {
    return 'TRL';
}

sub TTD {
    return 'TTD';
}

sub TWD {
    return 'TWD';
}

sub UAH {
    return 'UAH';
}

sub USD {
    return 'USD';
}

sub UYU {
    return 'UYU';
}

sub UZS {
    return 'UZS';
}

sub VEB {
    return 'VEB';
}

sub VND {
    return 'VND';
}

sub YER {
    return 'YER';
}

sub YUN {
    return 'YUN';
}

sub ZAR {
    return 'ZAR';
}

sub ZWD {
    return 'ZWD';
}

1;
